@@ -999,7 +999,8 @@ def more_tweets_required(df,consumerKey,consumerSecret,accessToken,accessTokenSe
 
 	
 def evaluate_NLP_profiles(data,keyword_corpus, hashtag_corpus):	
+	final_df= pd.DataFrame()
 	for i in range(len(data)):
-		profile_evaluated, tweets_df = NLP_analysis(data.iloc[i], keyword_corpus, hashtags_corpus)
-		data.iloc[i] = profile_evaluated	
-	return data
\ No newline at end of file
+		profile_evaluated, tweets_df = NLP_analysis(data.iloc[i], keyword_corpus, hashtag_corpus)
+		final_df = final_df.append(profile_evaluated, ignore_index=True)
+	return final_df
\ No newline at end of file
